Documentation
¶
Index ¶
- func MaxVisibleWidth(content string) int
- func OpenPopupCmd(popupType, commit string) tea.Cmd
- func PadRight(s string, width int) string
- func PadToHeight(s string, height int) string
- func TruncateString(s string, maxRunes int) string
- func YankCmd(text string) tea.Cmd
- type OpenCommitLinkMsg
- type OpenCommitViewMsg
- type OpenPopupMsg
- type YankMsg
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MaxVisibleWidth ¶
MaxVisibleWidth returns the maximum visible width across all lines in content.
func OpenPopupCmd ¶
OpenPopupCmd returns a command that emits OpenPopupMsg.
func PadToHeight ¶
PadToHeight ensures the string has at least height lines.
func TruncateString ¶
TruncateString truncates a string to maxRunes runes.
Types ¶
type OpenCommitLinkMsg ¶
type OpenCommitLinkMsg struct{ Hash string }
OpenCommitLinkMsg requests opening a commit URL in a browser.
type OpenCommitViewMsg ¶
type OpenCommitViewMsg struct{ Hash string }
OpenCommitViewMsg requests opening the commit view for a hash.
type OpenPopupMsg ¶
OpenPopupMsg requests opening a popup of the given type.
Click to show internal directories.
Click to hide internal directories.