Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RepoChangedMsg ¶
type RepoChangedMsg struct{}
RepoChangedMsg is sent when the watcher detects a change in the git directory.
type Watcher ¶
type Watcher struct {
// contains filtered or unexported fields
}
Watcher monitors the .git directory for changes and sends RepoChangedMsg.
func New ¶
New creates a new Watcher for the given .git directory. Missing optional paths (MERGE_HEAD, etc.) are silently skipped.
Click to show internal directories.
Click to hide internal directories.